Skip to contents

Standardized cross-sectional test that is robust to event-induced variance increases. The BMP test standardizes abnormal returns by their forecast error corrected standard deviation, then applies a cross-sectional t-test to these standardized residuals.

Super class

TestStatisticBase -> BMPTest

Public fields

name

Short code of the test statistic.

Methods

Inherited methods


BMPTest$compute()

Computes the BMP standardized cross-sectional test.

Usage

BMPTest$compute(data_tbl, model)

Arguments

data_tbl

The data for a multiple event with calculated abnormal returns.

model

The fitted model containing sigma estimates.


BMPTest$clone()

The objects of this class are cloneable with this method.

Usage

BMPTest$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.