Skip to contents

The Cross-Sectional Test (CSect T) is a statistical tool employed in event studies to evaluate the null hypothesis that the average abnormal return at the event date is zero. The test statistic is distributed as \(t_{N-1}\), where N is the number of events in that group.

See also https://eventstudy.de/statistics/aar_caar_statistics.html

Super class

TestStatisticBase -> CSectTTest

Public fields

name

Short code of the test statistic.

Methods

Inherited methods


CSectTTest$compute()

Computes the AAR/CAAR cross-sectional t test statistics.

Usage

CSectTTest$compute(data_tbl, model)

Arguments

data_tbl

The data for a multiple event with calculated abnormal returns.

model

The fitted model: not necessary for this test statistics.


CSectTTest$clone()

The objects of this class are cloneable with this method.

Usage

CSectTTest$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.