Skip to contents

Contains a set of multi event test statistics as, e.g., AAR and CAAR cross-sectional t test. These are the default test statistics.

Super class

StatisticsSetBase -> MultiEventStatisticsSet

Public fields

tests

Container with the statistical tests.

Methods

Inherited methods


MultiEventStatisticsSet$clone()

The objects of this class are cloneable with this method.

Usage

MultiEventStatisticsSet$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.