Skip to contents

Contains a set of single event test statistics as, e.g., AR and CAR t test. These are the default test statistics.

Super class

StatisticsSetBase -> SingleEventStatisticsSet

Public fields

tests

Container with the statistical tests.

Methods

Inherited methods


SingleEventStatisticsSet$clone()

The objects of this class are cloneable with this method.

Usage

SingleEventStatisticsSet$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.