Downloads risk-free rate data from the Kenneth French Data Library (extracted from the Fama-French factor files).
Usage
download_risk_free_rate(
frequency = c("daily", "monthly"),
source = "french",
format_for_task = TRUE
)Downloads risk-free rate data from the Kenneth French Data Library (extracted from the Fama-French factor files).
download_risk_free_rate(
frequency = c("daily", "monthly"),
source = "french",
format_for_task = TRUE
)