Train the defined model on each event and calculate the abnormal return.
Source:R/execute.R
fit_model.RdTrain the defined model on each event and calculate the abnormal return.
R/execute.R
fit_model.RdTrain the defined model on each event and calculate the abnormal return.