Create an event study plot from panel estimation results. Can also be
called via plot_event_study() when given a PanelEventStudyTask.
Create an event study plot from panel estimation results. Can also be
called via plot_event_study() when given a PanelEventStudyTask.