Buy-and-Hold Abnormal Return T Test (BHARTTest)
Source:R/single_event_test_statistics.R
BHARTTest.RdTests whether the BHAR for a single event is significantly different from zero. The BHAR is the difference between compounded firm returns and compounded benchmark returns over the event window.
Super class
TestStatisticBase -> BHARTTest