Event Study Task
The Event Study task contains all necessary data for performing an event study. Furthermore, all calculations are saved in the internal dataframe named data_tbl.
Public fields
data_tblAll calculations are saved in this dataframe. The dataframe is a nested object with each row is one event, identified by the event id, the group, and the firm symbol.
aar_caar_tblPlaceholder for AAR and CAAR test statistics.
.keysevent identifier. Do not change.
.indexThe time column name
.targetThe price column name.
.request_file_columnsThe necessary column names of the request dataframe.
factor_tblOptional factor data for multi-factor models (Fama-French, Carhart). Must contain a
datecolumn.
Active bindings
symbolsRead-only field to get the firm symbols.
symbol_dataRead-only field to get the firm symbol data.
group_level_dataRead-only field to get the group data.
Methods
EventStudyTask$new()
Create a new EventStudyTask from stock data, reference market data, and an event request specification.
Usage
EventStudyTask$new(
firm_stock_data_tbl,
reference_tbl,
request_tbl,
factor_tbl = NULL
)Arguments
firm_stock_data_tblDataframe with firm stock data. This dataframe must contain the stock (col: symbol) the date (col: date) and the price (col: adjusted) column.
reference_tblDataframe with firm reference data.
request_tblThe request dataframe for each event.
factor_tblOptional dataframe with factor data (e.g., Fama-French factors). Must contain a
datecolumn plus factor columns.
EventStudyTask$get_aar()
Extract average abnormal returns across events.