The Market Model is a widely used method in event studies to estimate the expected returns of a stock and calculate its abnormal returns during an event window. The model is based on a simple linear regression framework and captures the relationship between a stock’s return and the return of a market index, such as the S&P 500 or the Dow Jones Industrial Average. The underlying assumption of the Market Model is that a stock’s return is primarily influenced by market movements, along with a stock-specific idiosyncratic component.
Super class
ModelBase -> MarketModel
Public fields
model_nameName of the model.
formulaThe formula applied for calculating the market model
use_hacLogical. Use HAC (Newey-West) standard errors.
hac_lagInteger or NULL. Lag truncation for Newey-West. NULL uses the automatic bandwidth selection.