Base model class for event study. Each single event study will get its own model initialization and fitting. Therefore, the input DataFrame contains the data for a single Event Study. For custom models, except the child modles of the market model, several statistics must be included, namely sigma, degree_of_freedom, first_order_auto_correlation, residuals, forecast_error_corrected_sigma, and forecast_error_corrected_sigma_car. Part of these statistics are necessary for calculating the Event Study statistics.
Public fields
model_nameName of the model.
degenerate_modeResolved degenerate-input mode injected by fit_model() before fit() is called. Subclasses that implement the degenerate-input contract (MarketModel and Phase-2 models) read this field inside fit() via .resolve_degenerate_mode(self$degenerate_mode).
event_idEvent identifier threaded from the outer data_tbl row. Used in degenerate-input error/warning messages.
firm_symbolFirm identifier threaded from the outer data_tbl row. Used in degenerate-input error/warning messages.
Active bindings
statisticsRead-only field to get statistics.
modelRead-only field to get the fitted model.
is_fittedRead-only field to check if the model is fitted. Statistics object contains different model specific KPIs that describes the fitted model.