Contains a set of multi event test statistics as, e.g., AAR and CAAR cross-sectional t test. These are the default test statistics.
Super class
StatisticsSetBase -> MultiEventStatisticsSet
Contains a set of multi event test statistics as, e.g., AAR and CAAR cross-sectional t test. These are the default test statistics.
StatisticsSetBase -> MultiEventStatisticsSet