The parameter set defines the Event Study, e.g, the return calculation, the event study model, the AR, CAR, AAR, and CAAR test statistics that should be applied.
Public fields
return_calculationA R6 object for calculating returns.
return_modelA R6 object for fitting the desired model.
single_event_statisticssingle event test statistic R6 object.
multi_event_statisticsmulti event test statistic R6 object.
study_typeType of event study: "return" (default), "volume", or "volatility". Affects axis labels in plots.
degenerate_handlingControls how degenerate estimation data is handled. One of
"lenient"(default),"strict", orNULL(defer to package option or built-in default). See?degenerate-input-contractfor details.
Methods
ParameterSet$new()
Initialize the parameters that defines the Event Study that should be applied.
Usage
ParameterSet$new(
return_calculation = SimpleReturn$new(),
return_model = MarketModel$new(),
single_event_statistics = SingleEventStatisticsSet$new(),
multi_event_statistics = MultiEventStatisticsSet$new(),
degenerate_handling = NULL
)Arguments
return_calculationAn initialized return calculation class. Defaults to SimpleReturn.
return_modelAn initialized event study model. Defaults to MarketModel.
single_event_statisticsDefinition of single event test statistics. Defaults to SingleEventStatisticsSet (AR T and CAR T tests).
multi_event_statisticsDefinition of multiple event test statistics. Defaults to MultiEventStatisticsSet (CSect T test).
degenerate_handlingOne of
"lenient","strict", orNULL. See?degenerate-input-contract.