Patell or Standardized Residual Test (PatellZTest)
Source:R/multi_event_test_statistics.R
PatellZTest.RdThe Patell or Standardized Residual Test is a statistical tool employed in event studies to evaluate the null hypothesis that the average abnormal return at the event date is zero. The test statistics is approximately distributed as N(0, 1).
See also https://eventstudy.de/statistics/aar_caar_statistics.html
Super class
TestStatisticBase -> PatellZTest