Contains a set of single event test statistics as, e.g., AR and CAR t test. These are the default test statistics.
Super class
StatisticsSetBase -> SingleEventStatisticsSet
Contains a set of single event test statistics as, e.g., AR and CAR t test. These are the default test statistics.
StatisticsSetBase -> SingleEventStatisticsSet