Estimate synthetic control weights by minimizing the pre-treatment mean squared prediction error. Weights are non-negative and sum to one.
Usage
estimate_synthetic_control(
task,
method = c("quadprog", "optim"),
covariates = NULL
)Arguments
- task
A
SyntheticControlTask.- method
Optimization method:
"quadprog"(default, requires quadprog) or"optim"(usesstats::optimL-BFGS-B).- covariates
Optional character vector of covariate column names in both treated and donor data to include in the matching.