R/prepare_event_study.R
prepare_event_study.Rd
Perform return calculation for each stock and the corresponding reference market defined in the task and the parameter set.
prepare_event_study(task, parameter_set)
An Event Study task.
A parameter set that defines the Event Study.
The task object with returns and windows appended.